( cd lib ; rm -rf libc.so.5 )
( cd lib ; ln -sf libc.so.5.0.9 libc.so.5 )
( cd lib ; rm -rf libm.so.5 )
( cd lib ; ln -sf libm.so.5.0.0 libm.so.5 )
( cd lib ; rm -rf libcurses.so.1 )
( cd lib ; ln -sf libcurses.so.1.0.0 libcurses.so.1 )
( cd lib ; rm -rf libtermcap.so.2 )
( cd lib ; ln -sf libtermcap.so.2.0.0 libtermcap.so.2 )
